@@ -1,9 +1,6 @@
 from pathlib import Path
 
-import pytest
-import yaml
 from threedi_cmd.commands.settings import CachedConfig
-from .fixtures import cache_content
 
 
 def test_load_cached_config_no_file():
