@@ -1,13 +1,12 @@
-from uuid import uuid4
 from datetime import datetime
+from uuid import uuid4
+
 from threedi_api_client.api import ThreediApi
+from threedi_api_client.openapi.models import ThreediModel
+
 from threedi_cmd.parser import ScenarioParser
 
 
-class MockedThreedimodel:
-    id = 14
-    schematisation_id = None
-
 def test_parser():
     # Note: smoke test parser (including jinja2-time template rendering)
     organisation = "61f5a464c35044c19bc7d4b42d7f58cb"
@@ -16,7 +15,9 @@ def test_parser():
 
     context = {
         "threedimodel_id": threedimodel_id,
-        "threedimodel": MockedThreedimodel(),
+        "threedimodel": ThreediModel(
+            id=1, name="test", revision="1", slug="foo", inpy_version="bar"
+        ),
         "organisation_uuid": organisation,
         "simulation_name": simulation_name,
         "datetime_now": datetime.utcnow().isoformat(),
@@ -26,10 +27,10 @@ def test_parser():
 
     config = {
         "THREEDI_API_HOST": "http://localhost:8000/",
-        "THREEDI_API_USERNAME": "root",
+        "THREEDI_API_USERNAME": "__key__",
         "THREEDI_API_PASSWORD": "notused",
     }
 
-    client = ThreediApi(config=config)
+    client = ThreediApi(config=config, version="v3-beta")
     parser = ScenarioParser(file_path)
-    parser.parse(client, None, "scenarios/", context)
+    parser.parse(client, "scenarios/", context)
