@@ -1,9 +1,7 @@
 import pytest
 import yaml
-from threedi_cmd.commands.settings import ScenariosMeta
-from threedi_cmd.commands.settings import CachedConfig
 
-from .fixtures import cache_content, scenario_constant_rain_content
+from threedi_cmd.commands.settings import CachedConfig, ScenariosMeta
 
 
 def test_scenario_meta(tmp_path, scenario_constant_rain_content):
