@@ -1,16 +1,11 @@
 import asyncio
 from datetime import datetime
-from enum import Enum
+
 import typer
 
+from threedi_cmd.commands.callbacks import default_callback
 from threedi_cmd.console import console
 from threedi_cmd.models.monitor import ActiveSimulations
-from threedi_cmd.commands.callbacks import default_callback
-from threedi_cmd.commands.settings import (
-    Settings,
-    EndpointOption,
-    get_settings,
-)
 
 active_sims_app = typer.Typer(callback=default_callback)
 
@@ -40,7 +35,7 @@ def simulations(ctx: typer.Context):
         pass
     finally:
         console.print(
-            f":sparkles: Bye bye, hope to see you soon! :sparkles:",
+            ":sparkles: Bye bye, hope to see you soon! :sparkles:",
             style="success",
         )
 
