@@ -4,30 +4,26 @@ from datetime import datetime
 from pathlib import Path
 
 import click
-from threedi_api_client.openapi.api.v3_api import V3Api
+import typer
 import websockets
-from threedi_api_client.api import Configuration
-from threedi_api_client.openapi.exceptions import ApiException
-from rich.table import Table
 from rich import box
-from rich.prompt import Confirm
-from rich.prompt import Prompt, IntPrompt
 from rich.padding import Padding
 from rich.panel import Panel
-import typer
+from rich.prompt import Confirm, IntPrompt, Prompt
+from rich.table import Table
+from threedi_api_client.api import Configuration
+from threedi_api_client.openapi.api.v3_api import V3Api
+from threedi_api_client.openapi.exceptions import ApiException
 
-from threedi_cmd.commands.utils import download_files
-from threedi_cmd.commands.scenarios import scenarios
-from threedi_cmd.parser import ScenarioParser
-from threedi_cmd.console import console
-from threedi_cmd.commands.utils import PathPrompt
-from threedi_cmd.errors import ExitCodes
-from threedi_cmd.models.errors import ApiModelError
-from threedi_cmd.models.scenario import ResolveError
-from threedi_cmd.models.scenario import FailedStep
-from threedi_cmd.errors import LoadScenarioError
-from threedi_cmd.logger import get_logger
 from threedi_cmd.commands.callbacks import default_callback
+from threedi_cmd.commands.scenarios import scenarios
+from threedi_cmd.commands.utils import PathPrompt, download_files
+from threedi_cmd.console import console
+from threedi_cmd.errors import ExitCodes, LoadScenarioError
+from threedi_cmd.logger import get_logger
+from threedi_cmd.models.errors import ApiModelError
+from threedi_cmd.models.scenario import FailedStep, ResolveError
+from threedi_cmd.parser import ScenarioParser
 
 logger = get_logger("INFO")
 
@@ -73,9 +69,7 @@ def models(ctx: typer.Context):
         )
         for i, model in enumerate(threedi_models.results):
             if model.inp_success is True:
-                txt = (
-                    f":heavy_check_mark: [bold green]{model.inp_success}[/bold green] "
-                )
+                txt = f":heavy_check_mark: [bold green]{model.inp_success}[/bold green] "
             else:
                 txt = f"[bold red]{model.inp_success}[/bold red]"
             table.add_row(f"{model.id}", f"{model.name}", f"{model.revision_hash}", txt)
@@ -148,9 +142,7 @@ def simulations(
     remaining = simulations.count
     limit = DEFAULT_PAGER_SIZE
     offset = 0
-    while remaining == simulations.count or (
-        remaining > 0 and Confirm.ask("Show more?")
-    ):
+    while remaining == simulations.count or (remaining > 0 and Confirm.ask("Show more?")):
         simulations = simulations_api.simulations_list(limit=limit, offset=offset)
         for i, simulation in enumerate(simulations.results):
             status = simulations_api.simulations_status_list(simulation.id)
@@ -232,14 +224,11 @@ def run_scenario(
     ctx: typer.Context,
     scenario: int = typer.Option(
         None,
-        help="The ID of the scenario, as returned by the 'scenarios' command. "
-        "If not provided the scenarios command will be invoked so you can choose an ID",
+        help="The ID of the scenario, as returned by the 'scenarios' command. If not provided the scenarios command will be invoked so you can choose an ID",
     ),
     model_id: int = typer.Option(
         None,
-        help="The ID of the model you want to use, as returned by "
-        "the 'models' command. If not provided the models command will be invoked so you "
-        "can choose an ID",
+        help="The ID of the model you want to use, as returned by the 'models' command. If not provided the models command will be invoked so you can choose an ID",
     ),
     organisation: str = typer.Option(
         None, help="Unique-id of the organisation to set as default"
@@ -249,7 +238,6 @@ def run_scenario(
     if scenario is None:
         scenarios(ctx)
         scenario = IntPrompt.ask("Which scenario do you want to run? ID")
-
     scenario_to_run = ctx.obj.scenarios[scenario]["file"]
     parser = ScenarioParser(scenario_to_run)
 
@@ -287,7 +275,7 @@ def run_scenario(
     console.print(f":link: URL: {scenario.base_object.instance.url}")
 
     try:
-        console.rule(f"Starting scenario run...", style="bold blue")
+        console.rule("Starting scenario run...", style="bold blue")
         asyncio.run(scenario.execute())
     except KeyboardInterrupt:
         pass
@@ -303,7 +291,7 @@ def run_scenario(
             expand=True,
             box=box.DOUBLE,
             border_style="bold spring_green4",
-            title=f":sparkles: Finished :sparkles:",
+            title=":sparkles: Finished :sparkles:",
         )
         console.print(success_panel, justify="center")
 
@@ -375,9 +363,7 @@ def results(
         f.append(result_download)
     success = download_files(f, folder)
     if success:
-        console.print(
-            ":heavy_check_mark: Finished downloading results", style="success"
-        )
+        console.print(":heavy_check_mark: Finished downloading results", style="success")
     else:
         console.print(":collision: Not all files could be downloaded", style="error")
 
