@@ -1,12 +1,10 @@
 import typer
 
 from threedi_cmd.commands.active_simulations import active_sims_app
-from threedi_cmd.commands.scenarios import scenario_app
 from threedi_cmd.commands.api import api_app
+from threedi_cmd.commands.scenarios import scenario_app
 from threedi_cmd.commands.suite import suite_app
-from threedi_cmd.plugins.models import AppRegistry
-from threedi_cmd.plugins.models import AppMeta
-
+from threedi_cmd.plugins.models import AppMeta, AppRegistry
 
 core = typer.Typer()
 
