@@ -1,31 +1,31 @@
 from __future__ import annotations
-from dataclasses import dataclass, field, asdict
-from enum import Enum
-from pathlib import Path
+
+import json
 import sys
+from dataclasses import asdict, dataclass, field
+from enum import Enum
+from functools import lru_cache
+from pathlib import Path
 from typing import List
 from urllib.parse import urlparse
-from functools import lru_cache
-import json
 
 import click
 import yaml
 from rich.prompt import Prompt
-
-from threedi_api_client.threedi_api_client import ThreediApiClient, Configuration
-from threedi_api_client.openapi.exceptions import ApiException
-from threedi_api_client.api import ThreediApi
 from threedi_api_client.aio.threedi_api_client import (
     ThreediApiClient as AsyncThreediApiClient,
 )
+from threedi_api_client.api import ThreediApi
+from threedi_api_client.openapi.exceptions import ApiException
+from threedi_api_client.threedi_api_client import Configuration, ThreediApiClient
 
 try:
-    from threedi_api_client.auth import get_auth_token, refresh_api_key, is_token_usable
+    from threedi_api_client.auth import get_auth_token, is_token_usable, refresh_api_key
 except ImportError:
     from threedi_api_client.threedi_api_client import (
         get_auth_token,
-        refresh_api_key,
         is_token_usable,
+        refresh_api_key,
     )
 
 from threedi_cmd.console import console
@@ -96,7 +96,6 @@ class CachedConfig:
 
 @dataclass
 class ScenariosMeta:
-
     scenario_dir: Path = SCENARIO_DIR
 
     @property
@@ -112,7 +111,7 @@ class ScenariosMeta:
                     scenario_list.append(meta)
                 except KeyError:
                     raise AttributeError(
-                        f"The scenario definition is missing the 'meta' section"
+                        "The scenario definition is missing the 'meta' section"
                     )
         return scenario_list
 
