@@ -1,19 +1,23 @@
+from . import (
+    boundary_conditions,
+    breach,
+    initial_waterlevels,
+    lateral,
+    leakage,
+    postprocessing,
+    rain,
+    rasteredit,
+    revision,
+    savedstate,
+    settings,
+    sources_sinks,
+    structure_control,
+    substance,
+    waitfor,
+    wind,
+)
 from .actions import ActionWrapper
 from .simulation import SimulationWrapper
-from . import waitfor
-from . import savedstate
-from . import rain
-from . import lateral
-from . import sources_sinks
-from . import wind
-from . import breach
-from . import rasteredit
-from . import initial_waterlevels
-from . import structure_control
-from . import boundary_conditions
-from . import leakage
-from . import settings
-from . import revision
 
 # Define a list of WRAPPERS
 # A wrapper is an object that 'wraps' a certain
@@ -41,4 +45,6 @@ WRAPPERS = (
     + leakage.WRAPPERS
     + settings.WRAPPERS
     + revision.WRAPPERS
+    + postprocessing.WRAPPERS
+    + substance.WRAPPERS
 )
