@@ -1,29 +1,63 @@
-from .base import SimulationChildWrapper
-from threedi_api_client.openapi.models import Action
-from .waitfor import WaitForStatusWrapper, WaitForTimeWrapper
+import logging
+from time import sleep
 
 from rich.live import Live
+from threedi_api_client.openapi.exceptions import ApiException
+from threedi_api_client.openapi.models import Action
 
 from threedi_cmd.console import console
+from threedi_cmd.logger import log_settings
+
+from .base import SimulationChildWrapper
+from .waitfor import WaitForStatusWrapper, WaitForTimeWrapper
+
+logger = logging.getLogger(__name__)
+
+MAX_RETRIES = 10
 
 
 class ActionWrapper(SimulationChildWrapper):
     model = Action
     api_path: str = "actions"
-    scenario_name = "action"
+    scenario_name = model.__name__.lower()
 
-    def create(self):
-        with Live(console=console) as live:
-            live.update(f"Creating {self.model.__name__}...")
-            func = getattr(self.api, f"{self.base_path}{self.api_path}_create")
+    def create(self, retry_count: int = 0):
+        """Try to create the action, retrying if no more sessions are available"""
+        if retry_count > MAX_RETRIES:
+            raise Exception("Failed to execute simulation create action after 10 retries")
 
-            data = self.instance.to_dict()
-            data = {key: item for key, item in data.items() if item is not None}
+        try:
+            if log_settings.get("use_rich_logging", False):
+                with Live(console=console) as live:
+                    live.update(f"Creating {self.model.__name__}...")
+                    func = getattr(self.api, f"{self.base_path}{self.api_path}_create")
+
+                    data = self.instance.to_dict()
+                    data = {key: item for key, item in data.items() if item is not None}
+
+                    res = func(self.simulation.id, data)
+                    live.update(
+                        f":heavy_check_mark: [bold spring_green4] Created {self.model.__name__}"
+                    )
+            else:
+                func = getattr(self.api, f"{self.base_path}{self.api_path}_create")
+                res = func(self.simulation.id, self.instance)
+        except ApiException as e:
+            if (
+                e.status == 429
+                and e.body is not None
+                and "has no more sessions available" in e.body
+            ):
+                retry_count += 1
+                sleep_time = retry_count**2
+                logger.info(
+                    f"No more sessions available, retrying... (waiting {sleep_time} seconds)"
+                )
+                sleep(sleep_time)
+                return self.create(retry_count)
+
+            raise e
 
-            res = func(self.simulation.id, data)
-            live.update(
-                f":heavy_check_mark: [bold spring_green4] Created {self.model.__name__}"
-            )
         console.print(self._data)
         return res
 
