@@ -1,18 +1,20 @@
 import json
+import logging
 from asyncio import Queue
 from inspect import isfunction
-from typing import Dict
-from threedi_api_client.openapi.api.v3_api import V3Api
-from threedi_api_client.openapi.models import Schematisation, Simulation
 from pathlib import Path
+from typing import Dict, Optional
+
 import requests
 from rich.live import Live
+from threedi_api_client.openapi.api.v3_api import V3Api
+from threedi_api_client.openapi.models import Schematisation, Simulation
 
 from threedi_cmd.console import console
+from threedi_cmd.logger import log_settings
 from threedi_cmd.models.errors import ApiModelError
-from threedi_cmd.logger import get_logger
 
-logger = get_logger("INFO")
+logger = logging.getLogger(__name__)
 
 
 def evaluate_lazy(value):
@@ -23,10 +25,7 @@ def evaluate_lazy(value):
 
 def class_repr(data, model):
     params = ", ".join(
-        [
-            f"{key}={json.dumps(str(evaluate_lazy(value)))}"
-            for key, value in data.items()
-        ]
+        [f"{key}={json.dumps(str(evaluate_lazy(value)))}" for key, value in data.items()]
     )
     return f"{model.__name__}({params})"
 
@@ -44,7 +43,7 @@ class BaseWrapper:
         self._base_path = base_path
         self._refs = refs
 
-    async def execute(self, queue: Queue):
+    async def execute(self, queue: Queue, steps: list):
         pass
 
     @property
@@ -58,11 +57,11 @@ BLACKLIST = {
 
 
 class ModelWrapper(BaseWrapper):
-    api_path: str = None
+    api_path: str = ""
     instance: object = None
     _internal_state = None
     model: object = None
-    scenario_name = None
+    scenario_name: str = ""
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -70,62 +69,80 @@ class ModelWrapper(BaseWrapper):
         self.api: V3Api = self._api_client  # noqa
 
         # Add self to refs
-        if "_ref" in self._data:
+        if self._data is not None and "_ref" in self._data:
             self._refs[self._data["_ref"]] = self.instance
 
     def resolve_func_name(self, suffix: str):
         func = getattr(self._api_client, f"{self.api_path}{suffix}")
         return func
 
-    def initialize_instance(self, data: Dict):
+    def initialize_instance(self, data: Optional[Dict] = None) -> None:
         """raises ApiModelError if initializing the instance fails"""
-        new_data = {
-            key: value
-            for key, value in data.items()
-            if not key.startswith("_") and key not in BLACKLIST
-        }
+        new_data = {}
+        if data is not None:
+            new_data = {
+                key: value
+                for key, value in data.items()
+                if not key.startswith("_") and key not in BLACKLIST
+            }
         try:
             self.instance = self.model(**new_data)
-        except ValueError as err:
+        except Exception as err:
             msg = f"Initializing {self.model.__name__} failed: {err}"
             raise ApiModelError(msg)
 
-    async def execute(self, queue):
+    async def execute(self, queue: Queue, steps: list) -> list:
         # By default save()
         self.save()
         for step in self.extra_steps:
-            await step.execute(queue)
+            await step.execute(queue, steps)
+
+        return steps
 
     def create(self):
-        with Live(console=console) as live:
-            live.update(f"Creating {self.model.__name__}...")
+        if log_settings.get("use_rich_logging", False):
+            with Live(console=console) as live:
+                live.update(f"Creating {self.model.__name__}...")
+                func = self.resolve_func_name("_create")
+                res = func(self.instance)
+                live.update(
+                    f":heavy_check_mark: [bold spring_green4] Created {self.model.__name__}"
+                )
+        else:
             func = self.resolve_func_name("_create")
             res = func(self.instance)
-            live.update(
-                f":heavy_check_mark: [bold spring_green4] Created {self.model.__name__}"
-            )
+
         console.print(self._data)
         return res
 
     def patch(self, data):
-        with Live(console=console) as live:
-            live.update(f"Patching {self.model.__name__}...")
+        if log_settings.get("use_rich_logging", False):
+            with Live(console=console) as live:
+                live.update(f"Patching {self.model.__name__}...")
+                func = self.resolve_func_name("_partial_update")
+                res = func(self.instance.id, data)
+                live.update(
+                    f":heavy_check_mark: [bold spring_green4] Patched {self.model.__name__}"
+                )
+        else:
             func = self.resolve_func_name("_partial_update")
             res = func(self.instance.id, data)
-            live.update(
-                f":heavy_check_mark: [bold spring_green4] Patched {self.model.__name__}"
-            )
+
         console.print(self._data)
         return res
 
     def delete(self):
-        with Live(console=console) as live:
-            live.update(f"Deleting {self.model.__name__}...")
+        if log_settings.get("use_rich_logging", False):
+            with Live(console=console) as live:
+                live.update(f"Deleting {self.model.__name__}...")
+                func = self.resolve_func_name("_delete")
+                res = func(self.instance.id)
+                live.update(
+                    f":heavy_check_mark: [bold spring_green4] Deleted {self.model.__name__}"
+                )
+        else:
             func = self.resolve_func_name("_delete")
             res = func(self.instance.id)
-            live.update(
-                f":heavy_check_mark: [bold spring_green4] Deleted {self.model.__name__}"
-            )
         return res
 
     def save(self):
@@ -179,14 +196,18 @@ class SimulationTemplateWrapper(ModelWrapper):
         if id is not None:
             return
 
-        with Live(console=console) as live:
-            live.update(f"Creating {self.model.__name__}...")
+        if log_settings.get("use_rich_logging", False):
+            with Live(console=console) as live:
+                live.update(f"Creating {self.model.__name__}...")
+                func = self.resolve_func_name("")
+                res = func(self._data)
+                live.update(
+                    f":heavy_check_mark: [bold spring_green4] Created {self.model.__name__}"
+                )
+        else:
             func = self.resolve_func_name("")
             res = func(self._data)
-            live.update(
-                f":heavy_check_mark: [bold spring_green4] Created {self.model.__name__}"
-            )
-        console.print(res, type(res))
+
         self.instance = res
 
 
@@ -212,22 +233,34 @@ class SimulationChildWrapper(ModelWrapper):
         return func
 
     def create(self, *args, **kwargs):
-        with Live(console=console) as live:
-            live.update(f"Creating {self.model.__name__}...")
+        if log_settings.get("use_rich_logging", False):
+            with Live(console=console) as live:
+                live.update(f"Creating {self.model.__name__}...")
+                func = self.resolve_func_name("_create")
+                res = func(self.simulation.id, self.instance, *args, **kwargs)
+                live.update(
+                    f":heavy_check_mark: [bold spring_green4] Created {self.model.__name__}"
+                )
+        else:
             func = self.resolve_func_name("_create")
             res = func(self.simulation.id, self.instance, *args, **kwargs)
-            live.update(
-                f":heavy_check_mark: [bold spring_green4] Created {self.model.__name__}"
-            )
+
         console.print(self._data)
         return res
 
     def patch(self, data):
-        with Live(console=console) as live:
-            live.update(f"Patching {self.model}...")
+        if log_settings.get("use_rich_logging", False):
+            with Live(console=console) as live:
+                live.update(f"Patching {self.model}...")
+                func = self.resolve_func_name("_partial_update")
+                res = func(self.instance.id, self.simulation.id, data)
+                live.update(
+                    f":heavy_check_mark: [bold spring_green4] Patched {self.model}"
+                )
+        else:
             func = self.resolve_func_name("_partial_update")
             res = func(self.instance.id, self.simulation.id, data)
-            live.update(f":heavy_check_mark: [bold spring_green4] Patched {self.model}")
+
         return res
 
     def delete(self):
@@ -254,22 +287,34 @@ class SchematisationChildWrapper(ModelWrapper):
         return self.scenario_name
 
     def create(self, *args, **kwargs):
-        with Live(console=console) as live:
-            live.update(f"Creating {self.model.__name__}...")
+        if log_settings.get("use_rich_logging", False):
+            with Live(console=console) as live:
+                live.update(f"Creating {self.model.__name__}...")
+                func = self.resolve_func_name("_create")
+                res = func(self.schematisation.id, self.instance, *args, **kwargs)
+                live.update(
+                    f":heavy_check_mark: [bold spring_green4] Created {self.model.__name__}"
+                )
+        else:
             func = self.resolve_func_name("_create")
             res = func(self.schematisation.id, self.instance, *args, **kwargs)
-            live.update(
-                f":heavy_check_mark: [bold spring_green4] Created {self.model.__name__}"
-            )
+
         console.print(self._data)
         return res
 
     def patch(self, data):
-        with Live(console=console) as live:
-            live.update(f"Patching {self.model}...")
+        if log_settings.get("use_rich_logging", False):
+            with Live(console=console) as live:
+                live.update(f"Patching {self.model}...")
+                func = self.resolve_func_name("_partial_update")
+                res = func(self.instance.id, self.schematisation.id, data)
+                live.update(
+                    f":heavy_check_mark: [bold spring_green4] Patched {self.model}"
+                )
+        else:
             func = self.resolve_func_name("_partial_update")
             res = func(self.instance.id, self.schematisation.id, data)
-            live.update(f":heavy_check_mark: [bold spring_green4] Patched {self.model}")
+
         return res
 
     def delete(self):
@@ -301,24 +346,42 @@ class RevisionChildWrapper(SchematisationChildWrapper):
         return self.scenario_name
 
     def create(self, *args, **kwargs):
-        with Live(console=console) as live:
-            live.update(f"Creating {self.model.__name__}...")
+        if log_settings.get("use_rich_logging", False):
+            with Live(console=console) as live:
+                live.update(f"Creating {self.model.__name__}...")
+                func = self.resolve_func_name("_create")
+                res = func(
+                    self.revision.id,
+                    self.schematisation.id,
+                    self.instance,
+                    *args,
+                    **kwargs,
+                )
+                live.update(
+                    f":heavy_check_mark: [bold spring_green4] Created {self.model.__name__}"
+                )
+        else:
             func = self.resolve_func_name("_create")
             res = func(
                 self.revision.id, self.schematisation.id, self.instance, *args, **kwargs
             )
-            live.update(
-                f":heavy_check_mark: [bold spring_green4] Created {self.model.__name__}"
-            )
+
         console.print(self._data)
         return res
 
     def patch(self, data):
-        with Live(console=console) as live:
-            live.update(f"Patching {self.model}...")
+        if log_settings.get("use_rich_logging", False):
+            with Live(console=console) as live:
+                live.update(f"Patching {self.model}...")
+                func = self.resolve_func_name("_partial_update")
+                res = func(self.instance.id, self.schematisation.id, data)
+                live.update(
+                    f":heavy_check_mark: [bold spring_green4] Patched {self.model}"
+                )
+        else:
             func = self.resolve_func_name("_partial_update")
             res = func(self.instance.id, self.schematisation.id, data)
-            live.update(f":heavy_check_mark: [bold spring_green4] Patched {self.model}")
+
         return res
 
     def delete(self):
@@ -374,3 +437,7 @@ class SettingsWrapper(SimulationChildWrapper):
 
 class InitialWrapper(SimulationChildWrapper):
     base_path = "simulations_initial_"
+
+
+class LizardPostprocessingWrapper(SimulationChildWrapper):
+    base_path = "simulations_results_post_processing_lizard_"
