@@ -1,5 +1,5 @@
-from typing import Dict
 from pathlib import Path
+from typing import Dict
 
 from threedi_api_client.openapi.models import FileBoundaryCondition, Upload
 
@@ -9,13 +9,13 @@ from .waitfor import WaitForEventValidation
 
 class WaitForFileBoundaryConditionsWrapper(WaitForEventValidation):
     model = FileBoundaryCondition
-    scenario_name = "waitforfileboundaryconditions"
+    scenario_name = model.__name__.lower()
 
 
 class FileBoundaryConditionsWrapper(EventWrapper):
     model = Upload
     api_path: str = "boundaryconditions_file"
-    scenario_name = "fileboundaryconditions"
+    scenario_name = model.__name__.lower()
     filepath: Path = None
 
     def initialize_instance(self, data: Dict):
@@ -30,8 +30,10 @@ class FileBoundaryConditionsWrapper(EventWrapper):
             )
         )
         for file_boundaryconditions in file_boundary_conditions.results:
-            if file_boundaryconditions.file:
-                file_boundaryconditions.file.filename == self.instance.filename
+            if (
+                file_boundaryconditions.file
+                and file_boundaryconditions.file.filename == self.instance.filename
+            ):
                 bulk_event_instance = file_boundaryconditions
                 break
         assert bulk_event_instance is not None
