@@ -1,13 +1,15 @@
 from typing import Dict
+
 from threedi_api_client.openapi.api.v3_api import V3Api
 from threedi_api_client.openapi.models import (
-    OneDWaterLevel,
-    TwoDWaterLevel,
     GroundWaterLevel,
-    OneDWaterLevelPredefined,
-    TwoDWaterRaster,
     GroundWaterRaster,
+    OneDWaterLevel,
+    OneDWaterLevelPredefined,
+    TwoDWaterLevel,
+    TwoDWaterRaster,
 )
+
 from .base import InitialWrapper
 
 
@@ -15,21 +17,21 @@ class OneDWaterLevelWrapper(InitialWrapper):
     model = OneDWaterLevel
     base_path = "simulations_initial"
     api_path = "1d_water_level_constant"
-    scenario_name = "1dwaterlevelconstant"
+    scenario_name = model.__name__.lower()
 
 
 class OneDWaterLevelPredefinedWrapper(InitialWrapper):
     model = OneDWaterLevelPredefined
     base_path = "simulations_initial"
     api_path = "1d_water_level_predefined"
-    scenario_name = "1dwaterlevelpredefined"
+    scenario_name = model.__name__.lower()
 
 
 class TwoDWaterLevelWrapper(InitialWrapper):
     model = TwoDWaterLevel
     base_path = "simulations_initial"
     api_path = "2d_water_level_constant"
-    scenario_name = "2dwaterlevelconstant"
+    scenario_name = model.__name__.lower()
 
 
 class TwoDWaterLevelRasterError(Exception):
@@ -40,7 +42,7 @@ class TwoDWaterLevelRasterWrapper(InitialWrapper):
     model = TwoDWaterRaster
     base_path = "simulations_initial"
     api_path = "2d_water_level_raster"
-    scenario_name = "2dwaterlevelraster"
+    scenario_name = model.__name__.lower()
     lookup: str = None
 
     # initial_waterlevel__source_raster__type
@@ -77,9 +79,7 @@ class TwoDWaterLevelRasterWrapper(InitialWrapper):
 
             # Search through initial waterlevel options
             # for the correct one
-            found = [
-                x for x in res.results if int(x.source_raster_id) == int(raster.id)
-            ]
+            found = [x for x in res.results if int(x.source_raster_id) == int(raster.id)]
 
             if len(found) != 1:
                 raise TwoDWaterLevelRasterError(
@@ -99,14 +99,14 @@ class GroundWaterLevelWrapper(InitialWrapper):
     model = GroundWaterLevel
     base_path = "simulations_initial"
     api_path = "_groundwater_level_constant"
-    scenario_name = "groundwaterlevelconstant"
+    scenario_name = model.__name__.lower()
 
 
 class GroundWaterLevelRasterWrapper(InitialWrapper):
     model = GroundWaterRaster
     base_path = "simulations_initial"
     api_path = "_groundwater_level_raster"
-    scenario_name = "groundwaterlevelraster"
+    scenario_name = model.__name__.lower()
 
 
 WRAPPERS = [
