@@ -1,36 +1,43 @@
-from typing import Dict
+import shutil
 from pathlib import Path
-from threedi_api_client.openapi.api.v3_api import V3Api
+from typing import Callable
 
 from threedi_api_client.openapi.models import (
     ConstantLateral,
-    TimeseriesLateral,
     FileLateral,
+    TimeseriesLateral,
     UploadEventFile,
 )
+
 from .base import EventWrapper
 from .waitfor import WaitForEventValidation
 
 
+def filename_converter(config: dict, **kwargs: dict) -> dict:
+    """Return environment corrected configuration"""
+    config["filename"] = config.pop("file")
+    return config
+
+
 class WaitForConstantLateralWrapper(WaitForEventValidation):
     model = ConstantLateral
-    scenario_name = "waitforconstantlateral"
+    scenario_name = model.__name__.lower()
 
 
 class WaitForTimeseriesLateralWrapper(WaitForEventValidation):
     model = TimeseriesLateral
-    scenario_name = "waitfortimeserieslateral"
+    scenario_name = model.__name__.lower()
 
 
 class WaitForFileLateralWrapper(WaitForEventValidation):
     model = FileLateral
-    scenario_name = "waitforfilelateral"
+    scenario_name = model.__name__.lower()
 
 
 class ConstantLateralWrapper(EventWrapper):
     model = ConstantLateral
     api_path: str = "lateral_constant"
-    scenario_name = "constantlateral"
+    scenario_name = model.__name__.lower()
 
     @property
     def extra_steps(self):
@@ -45,7 +52,7 @@ class ConstantLateralWrapper(EventWrapper):
 class TimeseriesLateralWrapper(EventWrapper):
     model = TimeseriesLateral
     api_path: str = "lateral_timeseries"
-    scenario_name = "timeserieslateral"
+    scenario_name = model.__name__.lower()
 
     @property
     def extra_steps(self):
@@ -61,10 +68,21 @@ class FileLateralWrapper(EventWrapper):
     model = UploadEventFile
     api_path: str = "lateral_file"
     scenario_name = "filelateral"
-    filepath: Path = None
+    filepath: Path | None = None
+    converters: list[Callable] = [filename_converter]
 
-    def initialize_instance(self, data: Dict):
-        self.filepath = Path(data.pop("filepath"))
+    def initialize_instance(self, data: dict | None = None) -> None:
+        # Create a copy of the file
+        assert data is not None
+        converted_file = f"{data['filename'].split('.')[0]}_converted.json"
+        full_path = self._base_path / converted_file
+        if full_path.exists():
+            full_path.unlink()
+        shutil.copy(self._base_path / data["filename"], full_path)
+
+        # Set the filepath
+        data["filename"] = converted_file
+        self.filepath = Path(converted_file)
         super().initialize_instance(data)
 
     @property
@@ -73,8 +91,7 @@ class FileLateralWrapper(EventWrapper):
             simulation_pk=self.simulation.id
         )
         for file_lateral in file_laterals.results:
-            if file_lateral.file:
-                file_lateral.file.filename == self.instance.filename
+            if file_lateral.file and file_lateral.file.filename == self.instance.filename:
                 bulk_event_instance = file_lateral
                 break
         assert bulk_event_instance is not None
@@ -88,9 +105,9 @@ class FileLateralWrapper(EventWrapper):
 
 
 WRAPPERS = [
-    WaitForConstantLateralWrapper,
-    WaitForTimeseriesLateralWrapper,
-    WaitForFileLateralWrapper,
+    # WaitForConstantLateralWrapper,
+    # WaitForTimeseriesLateralWrapper,
+    # WaitForFileLateralWrapper,
     ConstantLateralWrapper,
     TimeseriesLateralWrapper,
     FileLateralWrapper,
