@@ -1,8 +1,10 @@
-from threedi_api_client.openapi.api.v3_api import V3Api
-from .base import EventWrapper
 from typing import Dict
+
+from threedi_api_client.openapi.api.v3_api import V3Api
 from threedi_api_client.openapi.models import RasterEdit
 
+from .base import EventWrapper
+
 
 class RasterEditError(Exception):
     pass
@@ -11,15 +13,14 @@ class RasterEditError(Exception):
 class RasterEditWrapper(EventWrapper):
     model = RasterEdit
     api_path: str = "raster_edits"
-    scenario_name = "rasteredit"
+    scenario_name = model.__name__.lower()
     raster_type = None
 
     def initialize_instance(self, data: Dict):
         self.raster_type = data.pop("raster__type", None)
         if self.raster_type is None and "raster" not in data:
             raise RasterEditError(
-                f"Please proved either `raster__type` or `raster`"
-                f"the RasterEdit: {data}"
+                f"Please proved either `raster__type` or `raster`the RasterEdit: {data}"
             )
 
         if self.raster_type is not None:
@@ -30,7 +31,7 @@ class RasterEditWrapper(EventWrapper):
             )
             if res.count != 1:
                 raise RasterEditError(
-                    f"Could not find raster_type, raster_list " f"response whas {res}"
+                    f"Could not find raster_type, raster_list response whas {res}"
                 )
 
             # Set raster
