@@ -1,27 +1,29 @@
 from pathlib import Path
 from typing import Dict
-from .base import SchematisationChildWrapper, RevisionChildWrapper
+
 from threedi_api_client.openapi.api import V3BetaApi
 from threedi_api_client.openapi.models import (
-    SchematisationRevision,
-    SqliteFileUpload,
-    RevisionRaster,
     Commit,
-    Upload,
+    RevisionRaster,
+    SchematisationRevision,
     Sqlite,
+    SqliteFileUpload,
+    Upload,
 )
+
+from .base import RevisionChildWrapper, SchematisationChildWrapper
 from .waitfor import WaitForModel
 
 
 class RevisionWrapper(SchematisationChildWrapper):
     model = SchematisationRevision
     api_path: str = "revisions"
-    scenario_name = "revision"
+    scenario_name = model.__name__.lower()
 
 
 class WaitForSqliteUploadWrapper(WaitForModel):
     model = Sqlite
-    scenario_name = "waitforsqliteupload"
+    scenario_name = model.__name__.lower()
     websocket_event_type = "event"
 
     def matches(self, websocket_instance):
@@ -34,7 +36,7 @@ class WaitForSqliteUploadWrapper(WaitForModel):
 
 class WaitForRasterUploadWrapper(WaitForModel):
     model = RevisionRaster
-    scenario_name = "waitforrevisionrastereupload"
+    scenario_name = model.__name__.lower()
     websocket_event_type = "event"
 
     def matches(self, websocket_instance):
@@ -48,7 +50,7 @@ class WaitForRasterUploadWrapper(WaitForModel):
 class SqliteWrapper(RevisionChildWrapper):
     model = SqliteFileUpload
     api_path: str = "revisions_sqlite_upload"
-    scenario_name = "sqlite"
+    scenario_name = model.__name__.lower()
     filepath: Path = None
 
     def resolve_func_name(self, suffix: str):
@@ -72,7 +74,7 @@ class SqliteWrapper(RevisionChildWrapper):
 class RasterWrapper(RevisionChildWrapper):
     model = RevisionRaster
     api_path: str = "revisions_rasters"
-    scenario_name = "raster"
+    scenario_name = model.__name__.lower()
     filepath: Path = None
     filename: str = None
 
@@ -106,7 +108,7 @@ class RasterWrapper(RevisionChildWrapper):
 class CommitWrapper(RevisionChildWrapper):
     model = Commit
     api_path: str = "revisions_commit"
-    scenario_name = "commit"
+    scenario_name = model.__name__.lower()
 
     def resolve_func_name(self, suffix: str):
         if suffix == "_create":
