@@ -1,8 +1,9 @@
-from .base import ModelWrapper
 from threedi_api_client.openapi.models import Simulation
 
+from .base import ModelWrapper
+
 
 class SimulationWrapper(ModelWrapper):
     model = Simulation
     api_path = "simulations"
-    scenario_name = "simulation"
+    scenario_name = model.__name__.lower()
