@@ -1,21 +1,21 @@
 import asyncio
 import json
 from typing import Optional
-import pkg_resources
 
 import websockets
+from websockets.asyncio.client import ClientConnection
 from websockets.http import Headers
-from threedi_cmd.commands.settings import WebSocketSettings
-from threedi_cmd.console import console
+
+from threedi_cmd.websockets.settings import WebSocketSettings
 
 
 class WebsocketClient(object):
     def __init__(self, settings: WebSocketSettings):
         self.settings = settings
-        self.websocket = None
-        self.do_listen = True
-        self.queue = asyncio.Queue()
-        self._connected = False
+        self.websocket: ClientConnection | None = None
+        self.do_listen: bool = True
+        self.queue: asyncio.Queue = asyncio.Queue()
+        self._connected: bool = False
 
     def get_queue(self):
         return self.queue
@@ -26,22 +26,15 @@ class WebsocketClient(object):
 
     @property
     def user_agent(self):
-        try:
-            return {
-                "user-agent": f"threedi-cmd-client/{pkg_resources.get_distribution('threedi-cmd').version}"
-            }
-        except pkg_resources.DistributionNotFound:
-            return {"user-agent": f"threedi-cmd-client/latest"}
+        return {"user-agent": "simulation-runner"}
 
     async def listen(self, endpoint_uri: str):
         uri = f"{self.settings.proto}://{self.settings.host}/{self.settings.api_version}/{endpoint_uri}"
-        console.log(f"• Trying to connect to {uri} now...")
         headers = Headers(authorization=f"{self.settings.token}")
         headers.update(**self.user_agent)
         sim_time: Optional[int] = None
-        async with websockets.connect(uri, extra_headers=headers) as websocket:
+        async with websockets.connect(uri, additional_headers=headers) as websocket:
             self.websocket = websocket
-            console.log(f"•  Connected to {uri}")
             self._connected = True
             async for message in websocket:
                 try:
@@ -55,7 +48,6 @@ class WebsocketClient(object):
                     await self.queue.put(message)
                 except websockets.exceptions.ConnectionClosedOK:
                     self.do_listen = False
-        console.print("• Websocket connection closed")
 
     async def close(self):
         self.do_listen = False
